@@ -22,7 +22,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_iotanalytics.type_defs import (
     ListChannelsResponseTypeDef,
@@ -45,20 +45,20 @@ __all__ = (
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
+    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListChannelsResponseTypeDef, None, None]:
+    ) -> Iterator[ListChannelsResponseTypeDef]:
         """
-        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels.paginate)
+        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels.paginate)
         """
 
 
 class ListDatasetContentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasetContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
+    [Paginator.ListDatasetContents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
     """
 
     def paginate(
@@ -67,46 +67,46 @@ class ListDatasetContentsPaginator(Boto3Paginator):
         scheduledOnOrAfter: datetime = None,
         scheduledBefore: datetime = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDatasetContentsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatasetContentsResponseTypeDef]:
         """
-        [ListDatasetContents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents.paginate)
+        [ListDatasetContents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents.paginate)
         """
 
 
 class ListDatasetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
+    [Paginator.ListDatasets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDatasetsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatasetsResponseTypeDef]:
         """
-        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets.paginate)
+        [ListDatasets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets.paginate)
         """
 
 
 class ListDatastoresPaginator(Boto3Paginator):
     """
-    [Paginator.ListDatastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
+    [Paginator.ListDatastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListDatastoresResponseTypeDef, None, None]:
+    ) -> Iterator[ListDatastoresResponseTypeDef]:
         """
-        [ListDatastores.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores.paginate)
+        [ListDatastores.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores.paginate)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
+    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPipelinesResponseTypeDef, None, None]:
+    ) -> Iterator[ListPipelinesResponseTypeDef]:
         """
-        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines.paginate)
+        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines.paginate)
         """
